
/**
 * GridRenderer.java
 */
import java.lang.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;
import java.util.*;
import java.text.*;
import java.beans.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.text.*;
import javax.swing.table.*;
import javax.swing.border.*;

import jbc.beans.*;
import jbc.grid.*;

/*
 * This sample shows the abilities of some renderers.
 */
 
/**
 * Class:   GridRenderer
 */
public class GridRenderer extends GridRenderer_Abstract
   {
    /**
     * Constructor: GridRenderer
     * @return instance of GridRenderer
     */
    public GridRenderer()
       {
        super();
        Point screenLocation = new Point(0, 0);
        Dimension screenSize = getToolkit().getScreenSize();
        screenSize.width /= 2;
        screenSize.width -= (getSize().width / 2);
        screenSize.height /= 2;
        screenSize.height -= (getSize().height / 2);
        setLocation(screenLocation.x + screenSize.width,
                    screenLocation.y + screenSize.height);         
       } /* End of Constructor: GridRenderer */

    /**
     * Method: init_JbcGridTable <br>
     * @param Instance of jbc.grid.JbcGridTable
     * @return jbc.grid.JbcGridTable
     */
    protected jbc.grid.JbcGridTable init_JbcGridTable(jbc.grid.JbcGridTable self)
       {
        JbcGridDefaultTableModel tm = new GridTableModel();
        self.setModel(tm);
        super.init_JbcGridTable(self);

        self.setAlternateBackgroundColor(new java.awt.Color(232,232,255));        
        get_ColumnCheckBox().setCellRenderer(new JbcCellRendererBoolean());
        get_ColumnCheckBox().setCellEditor(new JbcCellEditorBoolean());
        get_ColumnCurrency().setCellRenderer(new JbcCellRendererDecimalFormat("#,##0.00"));
        get_ColumnCurrency().setCellEditor(new JbcCellEditorDecimalFormat());
        get_ColumnDecimal().setCellRenderer(new JbcCellRendererDecimalFormat());
        get_ColumnDecimal().setCellEditor(new JbcCellEditorDecimalFormat());
        get_ColumnDecimalSpinner().setCellRenderer(new JbcCellRendererDecimalFormat());
        get_ColumnDecimalSpinner().setCellEditor(new JbcCellEditorDouble(0,99999999,2));        
        get_ColumnScientific().setCellRenderer(new JbcCellRendererScientificNotation());
        get_ColumnScientific().setCellEditor(new JbcCellEditorScientificNotation());
        get_ColumnInteger().setCellRenderer(new JbcCellRendererRight());
        get_ColumnCustom().setCellRenderer(new CustomBufferedImageRenderer());        

        JbcCellEditorInteger ce = new JbcCellEditorInteger(0,100);
        final JbcSpinButton sb = (JbcSpinButton)ce.getComponent();
        sb.addChangeListener(new javax.swing.event.ChangeListener()
           {
            public void stateChanged(javax.swing.event.ChangeEvent e)
               {
                if (get_JbcGridTable().isEditing())
                   {
                    JTable table = get_JbcGridTable();
                    int row = table.getEditingRow();
                    int col = table.convertColumnIndexToView(get_ColumnBar().getModelIndex());
                    table.setValueAt(new Integer(sb.getValue()),row,col);
                   }
               }
           });
        get_ColumnInteger().setCellEditor(ce);

        get_ColumnBar().setCellEditor(new JbcCellEditorNoEditable());
        get_ColumnBar().setCellRenderer(new JbcCellRendererProgressBar());
        
        int modulo = 3;
        for (int i = 0; i < 10; i++)
           {
            Vector data = new Vector();
            if ((i % modulo ) == 0)
               {
                data.add(Boolean.TRUE);
                modulo *= 2;
               }
            else
               {
                data.add(Boolean.FALSE);
               }
            data.add(new Double(((i+1)*345678.9)/99.9));
            data.add(new Double(((i+1)*876543.2)/99.9));
            data.add(new Double((i+1)*6543.0));            
            data.add(new Double((((i+1)*3333.3)*555555)/99.9));
            Integer integer = new Integer((int)(System.currentTimeMillis()/(i+1)%100));
            data.add(integer);
            data.add(integer);
            BufferedImage image = new BufferedImage(10, 10, BufferedImage.TYPE_INT_RGB);
            Graphics2D g = (Graphics2D)image.getGraphics();
            g.setColor(Color.lightGray);
            g.fillRect(0, 0, 10, 10);
            g.draw3DRect(0, 0, 9, 9,true);
            g.dispose();  
            data.add(image);          
            tm.addRow(data);
           }
        return self;
       } /* End of Method: init_JbcGridTable */
       
    class GridTableModel extends JbcGridDefaultTableModel
       {
        public JComponent getExpandedTreeviewComponent(int row)
           {
            JLabel component = new JLabel("Simple-Component");
            component.setPreferredSize(new java.awt.Dimension(160,74));
            component.setBorder(new EtchedBorder(EtchedBorder.LOWERED));
            return component;
           }

        public boolean isExpandableTreeview(int row)
           {
            return row == 0;
           }
       }

    class CustomBufferedImageRenderer extends JLabel implements TableCellRenderer
       {
        CustomBufferedImageRenderer()
           {
            setHorizontalAlignment(SwingConstants.CENTER);  
            setOpaque(true);         
           }
         
        public Component getTableCellRendererComponent(JTable table, Object value, 
                boolean isSelected, boolean hasFocus, int row, int column)
           {           
            Icon icon = null;
            boolean expandedTreeview = false;
            if (table instanceof JbcGridTable)
                expandedTreeview = ((JbcGridTable)table).isExpandedTreeview(row - 1);
            if (!expandedTreeview && value instanceof BufferedImage)
                icon = new ImageIcon((BufferedImage)value);
            setIcon(icon);
            Color alternateBackgroundColor = table.getBackground();
            if (table instanceof JbcGridTable)
                alternateBackgroundColor = ((JbcGridTable)table).getAlternateBackgroundColor();
            if (isSelected)
                setBackground(table.getSelectionBackground()); 
            else if ((!isSelected) && (row | 1) == row)
                setBackground(alternateBackgroundColor);
            else
                setBackground(table.getBackground());                
            return this;
           }
       }
              
    /**
     * Method: generalHandleException <br>
     * @param java.lang.Throwable exception
     * @return void
     */
    protected void generalHandleException(java.lang.Throwable exc)
       {
        /* Remove this comment and specialize processing here. */
        exc.printStackTrace(System.err);
       } /* End of Method: generalHandleException */

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {       
        // Locale.setDefault(new Locale("en","US"));        
        try
           {
            /* Set native look and feel */
            javax.swing.UIManager.setLookAndFeel(javax.swing.UIManager.getSystemLookAndFeelClassName());
           }
        catch (Exception exc)
           {
           }
        GridRenderer self = new GridRenderer();
        self.get_JWindow().show();           
       } /* End of Method: main */

    /**
     * Method: JButton_action_actionPerformed <br>
     * Adapter: ActionAdapter <br>
     * Interface: java.awt.event.ActionListener <br>
     * Note  : This method is called when an action occurs.  <br>
     * @param java.awt.event.ActionEvent evt
     * @return void
     */
    protected void JButton_action_actionPerformed(java.awt.event.ActionEvent evt)
       {
        get_JWindow().hide(); 
        get_JFrame().show();       
       } /* End of Method: JButton_action_actionPerformed */

   } /* End of Class: GridRenderer */



