
/**
 * SimpleAddRemove.java
 */
import java.lang.*;
import java.util.*;
import java.awt.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.*;

import jbc.grid.*;

/*
 * This sample emphasizes precautions that should be taken to insert or remove rows. 
 * If a row is in an expanded state, you should first collapse it before removing it. 
 */

/**
 * Class:   SimpleAddRemove
 */
public class SimpleAddRemove extends javax.swing.JFrame
   {
    JButton addButton;
    JButton removeButton;

    /**
     * Constructor: SimpleAddRemove
     * @return instance of SimpleAddRemove
     */
    public SimpleAddRemove()
       {
        /* JFrame - Bean Properties */
        setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
        setTitle("SimpleAddRemove");
        /* JFrame - sets Bounds */
        setBounds(40, 40, 400, 400);
        final JbcGridTable aNewTable = createGridTable();
        getContentPane().add(new JScrollPane(aNewTable), java.awt.BorderLayout.CENTER);
        addButton = new JButton("Add");
        addButton.addActionListener(new java.awt.event.ActionListener()
           {
            public void actionPerformed(java.awt.event.ActionEvent e)
               {
                // Inserting a row :
                // 1) Determine the selected row
                // 2) Check out if the target-row is an expanded treeview row
                //    If yes, skip the row that contains the treeview component
                // 3) Insert the new row
                int row = aNewTable.getSelectedRow();
                if (row != -1)
                   {
                    if (aNewTable.isExpandedTreeview(row))
                        row++; // Skip the treeview component
                    GridTableModel tm = (GridTableModel)aNewTable.getModel();
                    Vector data = new Vector();
                    data.add("New " + new Date() + "/A"); // Data Column A
                    data.add("New " + new Date() + "/B"); // Data Column B
                    tm.insertRow(row+1,data);
                   }
                else
                   {
                    java.awt.Toolkit.getDefaultToolkit().beep();
                   }
               }
           });
        removeButton = new JButton("Remove");
        removeButton.addActionListener(new java.awt.event.ActionListener()
           {
            public void actionPerformed(java.awt.event.ActionEvent e)
               {
                // Removing a row :
                // 1) Determine the selected row
                // 2) Check out if the target-row is an expanded treeview component
                //    If yes, the selected row cannot be removed
                // 3) Check out if the target-row is an expanded treeview row
                //    If yes, collapse this row before removing it
                // 4) Remove the row
                int row = aNewTable.getSelectedRow();
                if (row != -1)
                   {
                    if (aNewTable.isExpandedTreeview(row-1))
                       {
                        java.awt.Toolkit.getDefaultToolkit().beep();
                        return; // Ignore the treeview component
                       }
                    if (aNewTable.isExpandedTreeview(row))
                        aNewTable.setExpandedTreeview(row,false); // Collapse the row
                    GridTableModel tm = (GridTableModel)aNewTable.getModel();
                    tm.removeRow(row);
                   }
                else
                   {
                    java.awt.Toolkit.getDefaultToolkit().beep();
                   }

               }
           });
        JPanel southPanel = new JPanel();
        southPanel.setLayout(new FlowLayout(FlowLayout.CENTER));
        southPanel.add(addButton);
        southPanel.add(removeButton);
        getContentPane().add(southPanel, java.awt.BorderLayout.SOUTH);
       }        /* End of Constructor: SimpleAddRemove */

    public JbcGridTable createGridTable()
       {
        JbcGridTable table = new JbcGridTable();
        table.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        GridTableModel tm = new GridTableModel();
        table.setModel(tm);
        /* Adds Column(s) */
        tm.addColumn("Column A");
        tm.addColumn("Column B");
        /* Adds Row(s) */
        for (int row = 0; row < 5; row++)
           {
            Vector data = new Vector();
            data.add("Text " + row + "/A"); // Data Column A
            data.add("Text " + row + "/B"); // Data Column B
            tm.addRow(data);
           }
        return table;
       }        /* End of Constructor: SimpleAddRemove */

    class GridTableModel extends JbcGridDefaultTableModel
       {
        JbcGridTable table;
        public JComponent getExpandedTreeviewComponent(int row)
           {
            table = createGridTable();
            return new JScrollPane(table);
           }

        public boolean isExpandableTreeview(int row)
           {
            return true;
           }
           
        public boolean isCellEditable(int row, int column)
           {
            return false;
           }
       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set Windows look and feel */
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");

            /* Creates new MainObject */
            SimpleAddRemove self = new SimpleAddRemove();
            self.show();
           }    /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           }    /* End catch */
       }        /* End of Method: main */

   }    /* End of Class: SimpleAddRemove */



