
/**
 * SimpleGridHuge.java
 */
import java.lang.*;
import java.awt.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

import jbc.grid.*;

/*
 * This sample uses JbcGridAbstractTableModel. This model inherits from the 
 * Java AbstractTableModel standard class. To be able to use this model, 
 * you should implement the Abstract methods, as required by the AbstractTableModel 
 * Java class. You are recommended to use this type of model when the number of rows is huge, 
 * when you are able to have a direct access to your data (e.g. from a data base). 
 * This model lets you free to implement methods that will allow data for each cell 
 * to be retrieved.
 */
 
/**
 * Class:   SimpleGridHuge
 */
public class SimpleGridHuge extends javax.swing.JFrame
   {
    /**
     * Constructor: SimpleGridHuge
     * @return instance of SimpleGridHuge
     */
    public SimpleGridHuge()
       {
        /* JFrame - Bean Properties */
        setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
        setTitle("SimpleGridHuge");
        /* JFrame - sets Bounds */
        setBounds(40, 40, 400, 400);
        JbcGridTable aNewTable = createGridTable(100000);
        getContentPane().add(new JScrollPane(aNewTable), java.awt.BorderLayout.CENTER);
       }        /* End of Constructor: SimpleGridHuge */

    public JbcGridTable createGridTable(int maxRows)
       {
        JbcGridTable table = new JbcGridTable();
        GridTableModel tm = new GridTableModel(table,maxRows);
        table.setModel(tm);
        return table;
       }        /* End of Constructor: SimpleGridHuge */

    class GridTableModel extends JbcGridAbstractTableModel
       {
        int dataBaseColumns = 2; // This value should be replaced by a dynamic query
        int dataBaseRows = 0;    // This value should be replaced by a dynamic query
        JbcGridTable gridTable;
        
        GridTableModel(JbcGridTable gridTable,int maxRows)
           {
            super();
            this.gridTable = gridTable;
            dataBaseRows = maxRows; // This value should be replaced by a dynamic query
           }
         
        public JComponent getExpandedTreeviewComponent(int row)
           {
            JbcGridTable aNewTable = createGridTable(3);
            return new JScrollPane(aNewTable);
           }
               
        public boolean isExpandableTreeview(int row)
           {
            return true;
           }

        public int getColumnCount()
           {
            return dataBaseColumns;
           }

        public int getRowCount()
           {
            int rows = dataBaseRows;
            if (gridTable != null)
                rows += gridTable.getExpandedTreeviewRowCount();
            return rows;
           }

        public String getColumnName(int column)
           {
            return "Column " + (column+1) + " of " + getColumnCount();
           }

        public Object getValueAt (int row, int column)
           {
            int realDataBaseRow = gridTable.convertRowToRealIndex(row);
            return "Text " + realDataBaseRow + " of " + dataBaseRows;
           }

        public boolean isCellEditable(int row, int column)
           {
            return false;
           }
           
       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set Windows look and feel */
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");

            /* Creates new MainObject */
            SimpleGridHuge self = new SimpleGridHuge();
            self.show();
           }    /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           }    /* End catch */
       }        /* End of Method: main */

   }    /* End of Class: SimpleGridHuge */



