
/**
 * SimpleGridHugeSort.java
 */
import java.lang.*;
import java.awt.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

import jbc.grid.*;

/*
 * This sample emphasizes which precaution to take when you wish a table to be re-sorted.
 *
 * This sample uses JbcGridAbstractTableModel. This model inherits from the 
 * Java AbstractTableModel standard class. To be able to use this model, 
 * you should implement the Abstract methods, as required by the AbstractTableModel 
 * Java class. You are recommended to use this type of model when the number of rows is huge, 
 * when you are able to have a direct access to your data (e.g. from a data base). 
 * This model lets you free to implement methods that will allow data for each cell 
 * to be retrieved.
 */
 
/**
 * Class:   SimpleGridHugeSort
 */
public class SimpleGridHugeSort extends javax.swing.JFrame
   {
    boolean sortUp = false;
    JButton sortButton;

    /**
     * Constructor: SimpleGridHugeSort
     * @return instance of SimpleGridHugeSort
     */
    public SimpleGridHugeSort()
       {
        /* JFrame - Bean Properties */
        setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
        setTitle("SimpleGridHugeSort");
        /* JFrame - sets Bounds */
        setBounds(40, 40, 400, 400);
        final JbcGridTable aNewTable = createGridTable(100000);
        getContentPane().add(new JScrollPane(aNewTable), java.awt.BorderLayout.CENTER);
        sortButton = new JButton("Sort");
        sortButton.addActionListener(new java.awt.event.ActionListener()
           {
            public void actionPerformed(java.awt.event.ActionEvent e)
               {
                /*
                 Re-sorting a table:
                 1) Retrieve the expanded treeview rows
                 2) Retrieve the selected rows                 
                 3) Collapse all the expanded treeview rows
                 4) Remove Row Selection                
                 5) Sort the table
                 6) Restore the expanded treeview rows that were expanded before sorting
                 7) Restore the selected rows that were selected before sorting
                 8) Repaint the table.
                */
                int[] expandedRows = aNewTable.getExpandedTreeviewRows(true);                
                aNewTable.collapseAllTreeviews();
                int maxRow = aNewTable.getRowCount();
                int[] selectedRows = aNewTable.getSelectedRows(); 
                aNewTable.removeRowSelectionInterval(0, maxRow-1);                 
                sortUp = !sortUp;
                for (int i = 0; i < expandedRows.length; i++)
                   {
                    int row = maxRow - 1 - expandedRows[i];
                    row = aNewTable.convertRealIndexToRow(row);
                    aNewTable.setExpandedTreeview(row,true);
                   }
                for (int i = 0; i < selectedRows.length; i++)
                   {
                    int row = maxRow - 1 - selectedRows[i];
                    row = aNewTable.convertRealIndexToRow(row);
                    aNewTable.addRowSelectionInterval(row,row);
                   }                   
                aNewTable.repaint();
               }
           });
        JPanel southPanel = new JPanel();
        southPanel.setLayout(new FlowLayout(FlowLayout.CENTER));
        southPanel.add(sortButton);
        getContentPane().add(southPanel, java.awt.BorderLayout.SOUTH);
       }        /* End of Constructor: SimpleGridHugeSort */

    public JbcGridTable createGridTable(int maxRows)
       {
        JbcGridTable table = new JbcGridTable();
        GridTableModel tm = new GridTableModel(table,maxRows);
        table.setModel(tm);
        return table;
       }        /* End of createGridTable */

    class GridTableModel extends JbcGridAbstractTableModel
       {
        int dataBaseColumns = 2; // This value should be replaced by a dynamic query
        int dataBaseRows = 0;    // This value should be replaced by a dynamic query
        JbcGridTable gridTable;

        GridTableModel(JbcGridTable gridTable,int maxRows)
           {
            super();
            this.gridTable = gridTable;
            dataBaseRows = maxRows; // This value should be replaced by a dynamic query
           }

        public JComponent getExpandedTreeviewComponent(int row)
           {
            JbcGridTable aNewTable = createGridTable(3);
            return new JScrollPane(aNewTable);
           }

        public boolean isExpandableTreeview(int row)
           {
            return true;
           }

        public int getColumnCount()
           {
            return dataBaseColumns;
           }

        public int getRowCount()
           {
            int rows = dataBaseRows;
            if (gridTable != null)
                rows += gridTable.getExpandedTreeviewRowCount();
            return rows;
           }

        public String getColumnName(int column)
           {
            return "Column " + (column+1) + " of " + getColumnCount();
           }

        public Object getValueAt (int row, int column)
           {
            int realDataBaseRow = gridTable.convertRowToRealIndex(row);
            if (sortUp)
                realDataBaseRow = dataBaseRows - 1 - realDataBaseRow;
            return "Text " + realDataBaseRow + " of " + dataBaseRows;
           }

        public boolean isCellEditable(int row, int column)
           {
            return false;
           }
           
       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set Windows look and feel */
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");

            /* Creates new MainObject */
            SimpleGridHugeSort self = new SimpleGridHugeSort();
            self.show();
           }    /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           }    /* End catch */
       }        /* End of Method: main */

   }    /* End of Class: SimpleGridHugeSort */



