
/**
 * SimpleGridHugeSortHeader.java
 */
import java.lang.*;
import java.awt.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

import jbc.grid.*;

/*
 * This sample emphasizes which precaution to take when you wish a table to be re-sorted.
 *
 * This sample uses JbcGridAbstractTableModel. This model inherits from the 
 * Java AbstractTableModel standard class. To be able to use this model, 
 * you should implement the Abstract methods, as required by the AbstractTableModel 
 * Java class. You are recommended to use this type of model when the number of rows is huge, 
 * when you are able to have a direct access to your data (e.g. from a data base). 
 * This model lets you free to implement methods that will allow data for each cell 
 * to be retrieved.
 */
 
/**
 * Class:   SimpleGridHugeSortHeader
 */
public class SimpleGridHugeSortHeader extends javax.swing.JFrame
   {
    boolean sortUp = false;
    JButton sortButton;

    /**
     * Constructor: SimpleGridHugeSortHeader
     * @return instance of SimpleGridHugeSortHeader
     */
    public SimpleGridHugeSortHeader()
       {
        /* JFrame - Bean Properties */
        setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
        setTitle("SimpleGridHugeSortHeader");
        /* JFrame - sets Bounds */
        setBounds(40, 40, 400, 400);
        JbcGridTable aNewTable = createGridTable(100000);
        new TableHeaderRenderer(aNewTable.getTableHeader());
        getContentPane().add(new JScrollPane(aNewTable), java.awt.BorderLayout.CENTER);
       }        /* End of Constructor: SimpleGridHugeSortHeader */

    public JbcGridTable createGridTable(int maxRows)
       {
        JbcGridTable table = new JbcGridTable();
        GridTableModel tm = new GridTableModel(table,maxRows);
        table.setModel(tm);
        return table;
       }        /* End of createGridTable */

     public void sort(JbcGridTable aTable)
        {
         /*
          Re-sorting a table:
          1) Retrieve the expanded treeview rows
          2) Retrieve the selected rows                 
          3) Collapse all the expanded treeview rows
          4) Remove Row Selection                
          5) Sort the table
          6) Restore the expanded treeview rows that were expanded before sorting
          7) Restore the selected rows that were selected before sorting
          8) Repaint the table.
         */
         int[] expandedRows = aTable.getExpandedTreeviewRows(true);
         aTable.collapseAllTreeviews();
         int maxRow = aTable.getRowCount();
         int[] selectedRows = aTable.getSelectedRows(); 
         aTable.removeRowSelectionInterval(0, maxRow-1);          
         sortUp = !sortUp;
         for (int i = 0; i < expandedRows.length; i++)
            {
             int row = maxRow - 1 - expandedRows[i];
             row = aTable.convertRealIndexToRow(row);
             aTable.setExpandedTreeview(row,true);
            }
         for (int i = 0; i < selectedRows.length; i++)
            {
             int row = maxRow - 1 - selectedRows[i];
             row = aTable.convertRealIndexToRow(row);
             aTable.addRowSelectionInterval(row,row);
            }             
         aTable.repaint();
        }
               
    class TableHeaderRenderer extends DefaultTableCellRenderer
       {
        final JTableHeader tableHeader;
        ImageIcon up;
        ImageIcon down;

        public TableHeaderRenderer(JTableHeader tableHeader)
           {
            super();
            this.tableHeader = tableHeader;
            tableHeader.setDefaultRenderer(this);
            tableHeader.addMouseListener(new HeaderMouseAdapter());
            up = getImageIcon("./Up.gif");
            down = getImageIcon("./Down.gif");
           }
           
        public Component getTableCellRendererComponent(JTable table, Object value,
                         boolean isSelected, boolean hasFocus, int row, int column)
           {
	     if (table != null)
                {
	         column = table.convertColumnIndexToModel(column);
                 JTableHeader header = table.getTableHeader();
	         if (header != null)
                    {
	             setForeground(header.getForeground());
	             setBackground(UIManager.getColor("control"));
	             setFont(header.getFont());
                     if (column == 0)
                        {
                         if (sortUp)
                             setIcon(up);
                         else
                             setIcon(down);                             
                        } 
                     else
                        setIcon(null);    
	            }
                }
             setText((value == null) ? "" : value.toString());
             setBorder(UIManager.getBorder("TableHeader.cellBorder"));
             setHorizontalAlignment(JLabel.CENTER);
	     return this;
            }
            
        class HeaderMouseAdapter extends java.awt.event.MouseAdapter
           {
            public void mouseClicked(java.awt.event.MouseEvent e)
               {
                if (e.getClickCount() == 1)
                    {
                     JbcGridTable table = (JbcGridTable)tableHeader.getTable();
                     int column = table.columnAtPoint(e.getPoint());
                     column = table.convertColumnIndexToModel(column);
                     if (column == 0)
                        {
                         sort(table); 
                         tableHeader.invalidate();
                         tableHeader.validate();
                         tableHeader.repaint();
                        }                                          
                    } 
               }
           }                                  
       }
           
    class GridTableModel extends JbcGridAbstractTableModel
       {
        int dataBaseColumns = 2; // This value should be replaced by a dynamic query
        int dataBaseRows = 0;    // This value should be replaced by a dynamic query
        JbcGridTable gridTable;

        GridTableModel(JbcGridTable gridTable,int maxRows)
           {
            super();
            this.gridTable = gridTable;
            dataBaseRows = maxRows; // This value should be replaced by a dynamic query
           }

        public JComponent getExpandedTreeviewComponent(int row)
           {
            JbcGridTable aNewTable = createGridTable(3);
            return new JScrollPane(aNewTable);
           }

        public boolean isExpandableTreeview(int row)
           {
            return true;
           }

        public int getColumnCount()
           {
            return dataBaseColumns;
           }

        public int getRowCount()
           {
            int rows = dataBaseRows;
            if (gridTable != null)
                rows += gridTable.getExpandedTreeviewRowCount();
            return rows;
           }

        public String getColumnName(int column)
           {
            return "Column " + (column+1) + " of " + getColumnCount();
           }

        public Object getValueAt (int row, int column)
           {
            int realDataBaseRow = gridTable.convertRowToRealIndex(row);
            if (sortUp)
                realDataBaseRow = dataBaseRows - 1 - realDataBaseRow;
            return "Text " + realDataBaseRow + " of " + dataBaseRows;
           }

        public boolean isCellEditable(int row, int column)
           {
            return false;
           }
           
       }

    /**
     * Method: getImageIcon <br>
     * @param java.lang.String (imagePath)
     * @return javax.swing.ImageIcon
     */
    protected javax.swing.ImageIcon getImageIcon(java.lang.String imagePath)
       {
        java.net.URL url = null;

        /* Try - ImagePath is a Class.Resource */
        try
           {
            javax.swing.ImageIcon imageIcon = new javax.swing.ImageIcon(getClass().getResource(imagePath));
            if (imageIcon != null)
               {
                return imageIcon;
               } /* End if */
           } /* End try */
        catch (java.lang.Throwable exc)
           {
           } /* End catch */

        /* Try - ImagePath is a System.Resource */
        try
           {
            url = java.lang.ClassLoader.getSystemResource(imagePath);
           } /* End try */
        catch (java.lang.Throwable exc)
           {
           } /* End catch */

        if (url == null)
           {
            /* Try - ImagePath is an URL */
            try
               {
                url = new java.net.URL(imagePath);
               } /* End try */
            catch (java.lang.Throwable exc)
               {
                return null;
               } /* End catch */
           } /* End if */
        return new javax.swing.ImageIcon(url);
       } /* End of Method: getImageIcon */
    
    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set Windows look and feel */
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");

            /* Creates new MainObject */
            SimpleGridHugeSortHeader self = new SimpleGridHugeSortHeader();
            self.show();
           }    /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           }    /* End catch */
       }        /* End of Method: main */

   }    /* End of Class: SimpleGridHugeSortHeader */



