
/**
 * SimpleGridVector.java
 */
import java.lang.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;

import jbc.grid.*;

/*
 * This sample uses JbcGridDefaultTableModel. This model inherits from the 
 * Java DefaultTableModel standard class. To be able to use this model, 
 * you should insert your data into a vector, as required by the DefaultTableModel 
 * Java class. You are recommended to use this type of model when the number of rows 
 * is not excessive or if you have not a direct access to your data. 
 * Using this model is very simple, you just have to provide a vector.
 */
 
/**
 * Class:   SimpleGridVector
 */
public class SimpleGridVector extends javax.swing.JFrame
   {
    /**
     * Constructor: SimpleGridVector
     * @return instance of SimpleGridVector
     */
    public SimpleGridVector()
       {
        /* JFrame - Bean Properties */
        setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
        setTitle("SimpleGridVector");
        /* JFrame - sets Bounds */
        setBounds(40, 40, 400, 400);
        JbcGridTable aNewTable = createGridTable();
        getContentPane().add(new JScrollPane(aNewTable), java.awt.BorderLayout.CENTER);
       }        /* End of Constructor: SimpleGridVector */

    public JbcGridTable createGridTable()
       {
        JbcGridTable table = new JbcGridTable();
        JbcGridDefaultTableModel tm = new GridTableModel();
        table.setModel(tm);
        /* Adds Column(s) */
        tm.addColumn("Column A");
        tm.addColumn("Column B");
        /* Adds Row(s) */
        for (int row = 0; row < 5; row++)
           {
            Vector data = new Vector();
            data.add("Text " + row + "/A"); // Data Column A
            data.add("Text " + row + "/B"); // Data Column B
            tm.addRow(data);
           }
        return table;
       }        /* End of Constructor: SimpleGridVector */

    class GridTableModel extends JbcGridDefaultTableModel
       {
        public JComponent getExpandedTreeviewComponent(int row)
           {
            JbcGridTable aNewTable = createGridTable();
            return new JScrollPane(aNewTable);
           }

        public boolean isExpandableTreeview(int row)
           {
            return true;
           }
           
        public boolean isCellEditable(int row, int column)
           {
            return false;
           }           
       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set Windows look and feel */
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");

            /* Creates new MainObject */
            SimpleGridVector self = new SimpleGridVector();
            self.show();
           }    /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           }    /* End catch */
       }        /* End of Method: main */

   }    /* End of Class: SimpleGridVector */



