
/**
 * SimpleGridVectorSort.java
 */
import java.lang.*;
import java.util.*;
import java.awt.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.table.*;

import jbc.grid.*;

/*
 * This sample emphasizes which precaution to take when you wish a table to be re-sorted.
 *
 * This sample uses JbcGridDefaultTableModel. This model inherits from the 
 * Java DefaultTableModel standard class. To be able to use this model, 
 * you should insert your data into a vector, as required by the DefaultTableModel 
 * Java class. You are recommended to use this type of model when the number of rows 
 * is not excessive or if you have not a direct access to your data. 
 * Using this model is very simple, you just have to provide a vector.
 */
 
/**
 * Class:   SimpleGridVectorSort
 */
public class SimpleGridVectorSort extends javax.swing.JFrame
   {
    JButton sortButton;

    /**
     * Constructor: SimpleGridVectorSort
     * @return instance of SimpleGridVectorSort
     */
    public SimpleGridVectorSort()
       {
        /* JFrame - Bean Properties */
        setDefaultCloseOperation(javax.swing.JFrame.EXIT_ON_CLOSE);
        setTitle("SimpleGridVectorSort");
        /* JFrame - sets Bounds */
        setBounds(40, 40, 400, 400);
        final JbcGridTable aNewTable = createGridTable();
        getContentPane().add(new JScrollPane(aNewTable), java.awt.BorderLayout.CENTER);
        sortButton = new JButton("Sort");
        sortButton.addActionListener(new java.awt.event.ActionListener()
           {
            public void actionPerformed(java.awt.event.ActionEvent e)
               {
                /*
                 Re-sorting a table:
                 1) Retrieve the expanded treeview rows
                 2) Retrieve the selected rows                 
                 3) Collapse all the expanded treeview rows
                 4) Remove Row Selection                
                 5) Sort the table
                 6) Restore the expanded treeview rows that were expanded before sorting
                 7) Restore the selected rows that were selected before sorting
                 8) Repaint the table.
                */
                int[] expandedRows = aNewTable.getExpandedTreeviewRows(true);
                aNewTable.collapseAllTreeviews();
                int maxRow = aNewTable.getRowCount();
                int[] selectedRows = aNewTable.getSelectedRows(); 
                aNewTable.removeRowSelectionInterval(0, maxRow-1);                 
                GridTableModel model = (GridTableModel)aNewTable.getModel();
                Vector data = model.getDataVector();
                Vector newData = new Vector(data.size());
                for (int i = 0; i < data.size(); i++)
                   {
                    newData.add(0,data.get(i));
                   }
                Vector columnIdentifiers = new Vector(2);
                columnIdentifiers.add("Column A");
                columnIdentifiers.add("Column B");
                model.setDataVector(newData,columnIdentifiers);
                for (int i = 0; i < expandedRows.length; i++)
                   {
                    int row = newData.indexOf(data.get(expandedRows[i]));
                    aNewTable.setExpandedTreeview(row,true);
                   }
                for (int i = 0; i < selectedRows.length; i++)
                   {
                    int row = newData.indexOf(data.get(selectedRows[i]));
                    aNewTable.addRowSelectionInterval(row,row);
                   }                    
               }
           });
        JPanel southPanel = new JPanel();
        southPanel.setLayout(new FlowLayout(FlowLayout.CENTER));
        southPanel.add(sortButton);
        getContentPane().add(southPanel, java.awt.BorderLayout.SOUTH);
       }        /* End of Constructor: SimpleGridVectorSort */

    public JbcGridTable createGridTable()
       {
        JbcGridTable table = new JbcGridTable();
        table.setSelectionMode(javax.swing.ListSelectionModel.SINGLE_SELECTION);
        GridTableModel tm = new GridTableModel();
        table.setModel(tm);
        /* Adds Column(s) */
        tm.addColumn("Column A");
        tm.addColumn("Column B");
        /* Adds Row(s) */
        for (int row = 0; row < 5; row++)
           {
            Vector data = new Vector();
            data.add("Text " + row + "/A"); // Data Column A
            data.add("Text " + row + "/B"); // Data Column B
            tm.addRow(data);
           }
        return table;
       }        /* End of createGridTable */

    class GridTableModel extends JbcGridDefaultTableModel
       {
        JbcGridTable table;
        public JComponent getExpandedTreeviewComponent(int row)
           {
            table = createGridTable();
            return new JScrollPane(table);
           }

        public boolean isExpandableTreeview(int row)
           {
            return true;
           }
           
        public boolean isCellEditable(int row, int column)
           {
            return false;
           }
       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set Windows look and feel */
            UIManager.setLookAndFeel("com.sun.java.swing.plaf.windows.WindowsLookAndFeel");

            /* Creates new MainObject */
            SimpleGridVectorSort self = new SimpleGridVectorSort();
            self.show();
           }    /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           }    /* End catch */
       }        /* End of Method: main */

   }    /* End of Class: SimpleGridVectorSort */



