
/**
 * SimpleSystemDirectory2.java
 */

import java.awt.*;
import java.util.*;
import java.io.*;
import javax.swing.*;  
import jbc.grid.*;

/**
 * Class:   SimpleSystemDirectory2
 */
public class SimpleSystemDirectory2 extends JFrame
   {
    /**
     * Constructor: SimpleSystemDirectory2
     * @return instance of SimpleSystemDirectory2
     */
    public SimpleSystemDirectory2()
       {
        /* Create Grid */
        JbcGridTable table = new JbcGridTable();
        SimpleSystemDirectory2Model model = new SimpleSystemDirectory2Model(table);
        table.setModel(model);

        /* Bean Properties */
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setTitle("Directory WITH JbcGridAbstractTableModel (Without Vector)");

        /* sets Bounds */
        setLocation(0,0);
        setSize(getToolkit().getScreenSize());
        getContentPane().add(new JScrollPane(table), BorderLayout.CENTER);
       } /* End of Constructor: SimpleSystemDirectory2 */

    class SimpleSystemDirectory2Model extends JbcGridAbstractTableModel
       {
        private String[] columnNames = 
           {
            "Name", "Size", "Type", "Modified"
           };
        private Class[] columnClasses = 
           {
            String.class, Integer.class, String.class, String.class            
           };
        FileNode fileNode;
        JbcGridTable gridTable;
        
        SimpleSystemDirectory2Model(JbcGridTable gridTable)
           {
            this(gridTable,new FileNode(new File("/.")));
           }

        SimpleSystemDirectory2Model(JbcGridTable gridTable,FileNode fileNode)
           {
            this.gridTable = gridTable;
            this.fileNode = fileNode;
           }

        public boolean isExpandableTreeview(int row)
           {
            int realDataBaseRow = gridTable.convertRowToRealIndex(row);
            FileNode[] children = fileNode.getChildren();
            FileNode child = children[realDataBaseRow]; 
            return child.isDirectory();
           }
                      
        public JComponent getExpandedTreeviewComponent(int row)
           {
            JbcGridTable table = new JbcGridTable();
            int realDataBaseRow = gridTable.convertRowToRealIndex(row);
            FileNode[] children = fileNode.getChildren();
            FileNode child = children[realDataBaseRow];            
            SimpleSystemDirectory2Model model = new SimpleSystemDirectory2Model(table,child);
            table.setModel(model);
            return new JScrollPane(table);
           }

        public int getRowCount()
           {
            int rows = fileNode.getChildCount();
            if (gridTable != null)
                rows += gridTable.getExpandedTreeviewRowCount();
            return rows;
           }

        public int getColumnCount()
           {
            return columnNames.length;
           }
        
        public String getColumnName(int column)
           {
            return columnNames[column];
           }

        public Class getColumnClass(int columnIndex)
           {
            return columnClasses[columnIndex];
           }

        public Object getValueAt(int row, int column)
           {        
            FileNode[] children = fileNode.getChildren();
            int realDataBaseRow = gridTable.convertRowToRealIndex(row);
            FileNode child = children[realDataBaseRow];
            switch (column)
               {
                case 0:
                   {
                    return child.toString();
                   }
                case 1:
                   {
                    return new Integer(child.getSize());
                   }
                case 2:
                   {
                    return child.getType();
                   }
                case 3:
                   {
                    return (new Date(child.lastModified())).toString();
                   }
               }
            return "Oops";
           }

       }

    class FileNode
       {
        File file;
        FileNode[] children;

        FileNode(File file)
           {
            this.file = file;
           }

        protected boolean isDirectory()
           {
            return file.isDirectory();
           }

        protected long lastModified()
           {
            return file.lastModified();
           }

        protected String getName()
           {
            return file.getName();
           }

        protected int getSize()
           {
            if (isDirectory())
                return getChildCount();
             return (int)file.length();            
           }

        protected String getType()
           {
            if (isDirectory())
                return "Directory";
            return "File";
           }
           
        protected int getChildCount()
           {
            return getChildren().length;
           }
        
        protected FileNode[] getChildren()
           {
            if (children != null)
                return children;
            File[] files = file.listFiles();
            if (files == null)
                files = new File[0];
            children = new FileNode[files.length];
            for (int i = 0; i < files.length; i++)
               {
                children[i] = new FileNode(files[i]);
               }
            return children;
           }
        
        public String toString()
           {
            return getName();
           } 
       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set native look and feel */
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
 
            /* Creates new MainObject */
            SimpleSystemDirectory2 self = new SimpleSystemDirectory2();
            self.show();
           } /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           } /* End catch */
       } /* End of Method: main */

   } /* End of Class: SimpleSystemDirectory2 */



