
/**
 * SimpleSystemDirectory3.java
 */

import java.awt.*;
import java.util.*;
import java.io.*;
import javax.swing.*;
import javax.swing.event.*;
import jbc.grid.*;

/**
 * Class:   SimpleSystemDirectory3
 */
public class SimpleSystemDirectory3 extends JFrame
   {
    JbcGridTable selectedGridTable;
    
    /**
     * Constructor: SimpleSystemDirectory3
     * @return instance of SimpleSystemDirectory3
     */
    public SimpleSystemDirectory3()
       {
        /* Create Grid */
        JbcGridTable table = new JbcGridTable();
        SimpleSystemDirectory3Model model = new SimpleSystemDirectory3Model();
        table.setModel(model);
        table.getSelectionModel().addListSelectionListener(new SingleTableSelection(table));

        /* Bean Properties */
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        setTitle("Directory WITH SingleTableSelection");

        /* sets Bounds */
        setLocation(0,0);
        setSize(getToolkit().getScreenSize());
        getContentPane().add(new JScrollPane(table), BorderLayout.CENTER);
       } /* End of Constructor: SimpleSystemDirectory3 */

    class SingleTableSelection implements ListSelectionListener
       {
         JbcGridTable table;
         SingleTableSelection(JbcGridTable table)
            {
             this.table = table;
            } 
         public void valueChanged(ListSelectionEvent e)
           {
            if (e.getFirstIndex() != -1 && e.getLastIndex() != -1)
               {
                if (selectedGridTable != null && selectedGridTable != table)
                   {
                    selectedGridTable.clearSelection();                                      
                   } 
                selectedGridTable = table;
               }
           }
       };
          
    class SimpleSystemDirectory3Model extends JbcGridDefaultTableModel
       {
        File file;
        static final String DIR  = "Directory";
        static final String FILE = "File";
        
        SimpleSystemDirectory3Model()
           {
            this(new File("/."));
           }
        
        SimpleSystemDirectory3Model(File file)
           {
            this.file = file;
            
            /* Adds Column(s) */
            addColumn("Name");
            addColumn("Size");
            addColumn("Type");
            addColumn("Modified"); 
                       
            /* Adds Row(s) */
            File[] children = file.listFiles();
            for (int row = 0; row < children.length; row++)
               {
                Vector data = new Vector();
                File child = children[row]; 
                data.add(child.getName());
                if (child.isDirectory())
                   {
                    data.add(new Integer(0));
                    data.add(DIR);                    
                   } 
                else
                   { 
                    data.add(new Integer((int)child.length())); 
                    data.add(FILE);                   
                   }                    
                data.add((new Date(child.lastModified())).toString());
                addRow(data);
               }
           }

        public boolean isExpandableTreeview(int row)
           { 
            return getValueAt(row,2).toString().equals(DIR);
           }
                      
        public JComponent getExpandedTreeviewComponent(int row)
           {
            String fileName = getValueAt(row,0).toString();
            File child = new File(file.toString() + File.separator + fileName); 
            JbcGridTable table = new JbcGridTable();                       
            table.setModel(new SimpleSystemDirectory3Model(child));
            table.getSelectionModel().addListSelectionListener(new SingleTableSelection(table));            
            return new JScrollPane(table);
           }

       }

    /**
     * Method: main <br>
     * Note: Called only if we're an application. <br>
     * @param java.lang.String[] args the command line arguments
     * @return void
     */
    public static void main(java.lang.String[] args)
       {
        try
           {
            /* Set native look and feel */
            UIManager.setLookAndFeel(UIManager.getSystemLookAndFeelClassName());
 
            /* Creates new MainObject */
            SimpleSystemDirectory3 self = new SimpleSystemDirectory3();
            self.show();
           } /* End try */
        catch (java.lang.Throwable exc)
           {
            exc.printStackTrace(System.err);
           } /* End catch */
       } /* End of Method: main */

   } /* End of Class: SimpleSystemDirectory3 */



